@@ -8,3 +8,8 @@ content data error
 """
 mail_thunder_content_set_compiler_error = "When set compiler using content make an error"
 mail_thunder_content_file_error = "MailThunder content file error"
+"""
+argparse
+"""
+mail_thunder_service_file_error = "service param -s got the wrong data"
+mail_thunder_login_error = "need set --user and --password to login"
